==> haskell-bzlib-0.5.2.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bzlib
version:              0.5.2.0
visibility:           public
id:                   bzlib-0.5.2.0-Cdru2H2CkgQKuI9dOOBkUT
key:                  bzlib-0.5.2.0-Cdru2H2CkgQKuI9dOOBkUT
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  a946f3be9726160e21e8ed9dfd0fda7f
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bzlib
hs-libraries:         HSbzlib-0.5.2.0-Cdru2H2CkgQKuI9dOOBkUT
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bzlib-0.5.2.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bzlib
version:              0.5.2.0
visibility:           public
id:                   bzlib-0.5.2.0-DL6IMTODeJP1mZTKDVQqpv
key:                  bzlib-0.5.2.0-DL6IMTODeJP1mZTKDVQqpv
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  443236ecba1f78e5c07a0b8fe1b40b4a
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bzlib
hs-libraries:         HSbzlib-0.5.2.0-DL6IMTODeJP1mZTKDVQqpv
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
